==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetRouteSpecGrpcRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property actions
 * @property matches
 * @property retryPolicies
 * @property timeouts
 */
public data class GetRouteSpecGrpcRoute(
    public val actions: List<GetRouteSpecGrpcRouteAction>,
    public val matches: List<GetRouteSpecGrpcRouteMatch>,
    public val retryPolicies: List<GetRouteSpecGrpcRouteRetryPolicy>,
    public val timeouts: List<GetRouteSpecGrpcRouteTimeout>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetRouteSpecGrpcRoute):
            GetRouteSpecGrpcRoute = GetRouteSpecGrpcRoute(
            actions = javaType.actions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecGrpcRouteAction.Companion.toKotlin(args0)
                })
            }),
            matches = javaType.matches().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecGrpcRouteMatch.Companion.toKotlin(args0)
                })
            }),
            retryPolicies = javaType.retryPolicies().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecGrpcRouteRetryPolicy.Companion.toKotlin(args0)
                })
            }),
            timeouts = javaType.timeouts().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecGrpcRouteTimeout.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetRouteSpecGrpcRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property actions
 * @property matches
 * @property retryPolicies
 * @property timeouts
 */
public data class GetRouteSpecGrpcRoute(
    public val actions: List<GetRouteSpecGrpcRouteAction>,
    public val matches: List<GetRouteSpecGrpcRouteMatch>,
    public val retryPolicies: List<GetRouteSpecGrpcRouteRetryPolicy>,
    public val timeouts: List<GetRouteSpecGrpcRouteTimeout>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetRouteSpecGrpcRoute): GetRouteSpecGrpcRoute = GetRouteSpecGrpcRoute(
            actions = javaType.actions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecGrpcRouteAction.Companion.toKotlin(args0)
                })
            }),
            matches = javaType.matches().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecGrpcRouteMatch.Companion.toKotlin(args0)
                })
            }),
            retryPolicies = javaType.retryPolicies().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecGrpcRouteRetryPolicy.Companion.toKotlin(args0)
                })
            }),
            timeouts = javaType.timeouts().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecGrpcRouteTimeout.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
